# -*- coding: utf-8 -*-
#
# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Unit tests."""

import mock
import pytest

from google.rpc import status_pb2

from google.cloud import automl_v1beta1
from google.cloud.automl_v1beta1.proto import column_spec_pb2
from google.cloud.automl_v1beta1.proto import dataset_pb2
from google.cloud.automl_v1beta1.proto import io_pb2
from google.cloud.automl_v1beta1.proto import model_evaluation_pb2
from google.cloud.automl_v1beta1.proto import model_pb2
from google.cloud.automl_v1beta1.proto import service_pb2
from google.cloud.automl_v1beta1.proto import table_spec_pb2
from google.longrunning import operations_pb2
from google.protobuf import empty_pb2


class MultiCallableStub(object):
    """Stub for the grpc.UnaryUnaryMultiCallable interface."""

    def __init__(self, method, channel_stub):
        self.method = method
        self.channel_stub = channel_stub

    def __call__(self, request, timeout=None, metadata=None, credentials=None):
        self.channel_stub.requests.append((self.method, request))

        response = None
        if self.channel_stub.responses:
            response = self.channel_stub.responses.pop()

        if isinstance(response, Exception):
            raise response

        if response:
            return response


class ChannelStub(object):
    """Stub for the grpc.Channel interface."""

    def __init__(self, responses=[]):
        self.responses = responses
        self.requests = []

    def unary_unary(self, method, request_serializer=None, response_deserializer=None):
        return MultiCallableStub(method, self)


class CustomException(Exception):
    pass


class TestAutoMlClient(object):
    def test_create_dataset(self):
        # Setup Expected Response
        name = "name3373707"
        display_name = "displayName1615086568"
        description = "description-1724546052"
        example_count = 1517063674
        etag = "etag3123477"
        expected_response = {
            "name": name,
            "display_name": display_name,
            "description": description,
            "example_count": example_count,
            "etag": etag,
        }
        expected_response = dataset_pb2.Dataset(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        parent = client.location_path("[PROJECT]", "[LOCATION]")
        dataset = {}

        response = client.create_dataset(parent, dataset)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = service_pb2.CreateDatasetRequest(
            parent=parent, dataset=dataset
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_create_dataset_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup request
        parent = client.location_path("[PROJECT]", "[LOCATION]")
        dataset = {}

        with pytest.raises(CustomException):
            client.create_dataset(parent, dataset)

    def test_update_dataset(self):
        # Setup Expected Response
        name = "name3373707"
        display_name = "displayName1615086568"
        description = "description-1724546052"
        example_count = 1517063674
        etag = "etag3123477"
        expected_response = {
            "name": name,
            "display_name": display_name,
            "description": description,
            "example_count": example_count,
            "etag": etag,
        }
        expected_response = dataset_pb2.Dataset(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        dataset = {}

        response = client.update_dataset(dataset)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = service_pb2.UpdateDatasetRequest(dataset=dataset)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_update_dataset_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup request
        dataset = {}

        with pytest.raises(CustomException):
            client.update_dataset(dataset)

    def test_get_dataset(self):
        # Setup Expected Response
        name_2 = "name2-1052831874"
        display_name = "displayName1615086568"
        description = "description-1724546052"
        example_count = 1517063674
        etag = "etag3123477"
        expected_response = {
            "name": name_2,
            "display_name": display_name,
            "description": description,
            "example_count": example_count,
            "etag": etag,
        }
        expected_response = dataset_pb2.Dataset(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        name = client.dataset_path("[PROJECT]", "[LOCATION]", "[DATASET]")

        response = client.get_dataset(name)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = service_pb2.GetDatasetRequest(name=name)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_get_dataset_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup request
        name = client.dataset_path("[PROJECT]", "[LOCATION]", "[DATASET]")

        with pytest.raises(CustomException):
            client.get_dataset(name)

    def test_list_datasets(self):
        # Setup Expected Response
        next_page_token = ""
        datasets_element = {}
        datasets = [datasets_element]
        expected_response = {"next_page_token": next_page_token, "datasets": datasets}
        expected_response = service_pb2.ListDatasetsResponse(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        parent = client.location_path("[PROJECT]", "[LOCATION]")

        paged_list_response = client.list_datasets(parent)
        resources = list(paged_list_response)
        assert len(resources) == 1

        assert expected_response.datasets[0] == resources[0]

        assert len(channel.requests) == 1
        expected_request = service_pb2.ListDatasetsRequest(parent=parent)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_list_datasets_exception(self):
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup request
        parent = client.location_path("[PROJECT]", "[LOCATION]")

        paged_list_response = client.list_datasets(parent)
        with pytest.raises(CustomException):
            list(paged_list_response)

    def test_delete_dataset(self):
        # Setup Expected Response
        expected_response = {}
        expected_response = empty_pb2.Empty(**expected_response)
        operation = operations_pb2.Operation(
            name="operations/test_delete_dataset", done=True
        )
        operation.response.Pack(expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        name = client.dataset_path("[PROJECT]", "[LOCATION]", "[DATASET]")

        response = client.delete_dataset(name)
        result = response.result()
        assert expected_response == result

        assert len(channel.requests) == 1
        expected_request = service_pb2.DeleteDatasetRequest(name=name)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_delete_dataset_exception(self):
        # Setup Response
        error = status_pb2.Status()
        operation = operations_pb2.Operation(
            name="operations/test_delete_dataset_exception", done=True
        )
        operation.error.CopyFrom(error)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        name = client.dataset_path("[PROJECT]", "[LOCATION]", "[DATASET]")

        response = client.delete_dataset(name)
        exception = response.exception()
        assert exception.errors[0] == error

    def test_import_data(self):
        # Setup Expected Response
        expected_response = {}
        expected_response = empty_pb2.Empty(**expected_response)
        operation = operations_pb2.Operation(
            name="operations/test_import_data", done=True
        )
        operation.response.Pack(expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        name = client.dataset_path("[PROJECT]", "[LOCATION]", "[DATASET]")
        input_config = {}

        response = client.import_data(name, input_config)
        result = response.result()
        assert expected_response == result

        assert len(channel.requests) == 1
        expected_request = service_pb2.ImportDataRequest(
            name=name, input_config=input_config
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_import_data_exception(self):
        # Setup Response
        error = status_pb2.Status()
        operation = operations_pb2.Operation(
            name="operations/test_import_data_exception", done=True
        )
        operation.error.CopyFrom(error)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        name = client.dataset_path("[PROJECT]", "[LOCATION]", "[DATASET]")
        input_config = {}

        response = client.import_data(name, input_config)
        exception = response.exception()
        assert exception.errors[0] == error

    def test_export_data(self):
        # Setup Expected Response
        expected_response = {}
        expected_response = empty_pb2.Empty(**expected_response)
        operation = operations_pb2.Operation(
            name="operations/test_export_data", done=True
        )
        operation.response.Pack(expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        name = client.dataset_path("[PROJECT]", "[LOCATION]", "[DATASET]")
        output_config = {}

        response = client.export_data(name, output_config)
        result = response.result()
        assert expected_response == result

        assert len(channel.requests) == 1
        expected_request = service_pb2.ExportDataRequest(
            name=name, output_config=output_config
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_export_data_exception(self):
        # Setup Response
        error = status_pb2.Status()
        operation = operations_pb2.Operation(
            name="operations/test_export_data_exception", done=True
        )
        operation.error.CopyFrom(error)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        name = client.dataset_path("[PROJECT]", "[LOCATION]", "[DATASET]")
        output_config = {}

        response = client.export_data(name, output_config)
        exception = response.exception()
        assert exception.errors[0] == error

    def test_create_model(self):
        # Setup Expected Response
        name = "name3373707"
        display_name = "displayName1615086568"
        dataset_id = "datasetId-2115646910"
        expected_response = {
            "name": name,
            "display_name": display_name,
            "dataset_id": dataset_id,
        }
        expected_response = model_pb2.Model(**expected_response)
        operation = operations_pb2.Operation(
            name="operations/test_create_model", done=True
        )
        operation.response.Pack(expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        parent = client.location_path("[PROJECT]", "[LOCATION]")
        model = {}

        response = client.create_model(parent, model)
        result = response.result()
        assert expected_response == result

        assert len(channel.requests) == 1
        expected_request = service_pb2.CreateModelRequest(parent=parent, model=model)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_create_model_exception(self):
        # Setup Response
        error = status_pb2.Status()
        operation = operations_pb2.Operation(
            name="operations/test_create_model_exception", done=True
        )
        operation.error.CopyFrom(error)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        parent = client.location_path("[PROJECT]", "[LOCATION]")
        model = {}

        response = client.create_model(parent, model)
        exception = response.exception()
        assert exception.errors[0] == error

    def test_get_model(self):
        # Setup Expected Response
        name_2 = "name2-1052831874"
        display_name = "displayName1615086568"
        dataset_id = "datasetId-2115646910"
        expected_response = {
            "name": name_2,
            "display_name": display_name,
            "dataset_id": dataset_id,
        }
        expected_response = model_pb2.Model(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        name = client.model_path("[PROJECT]", "[LOCATION]", "[MODEL]")

        response = client.get_model(name)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = service_pb2.GetModelRequest(name=name)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_get_model_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup request
        name = client.model_path("[PROJECT]", "[LOCATION]", "[MODEL]")

        with pytest.raises(CustomException):
            client.get_model(name)

    def test_list_models(self):
        # Setup Expected Response
        next_page_token = ""
        model_element = {}
        model = [model_element]
        expected_response = {"next_page_token": next_page_token, "model": model}
        expected_response = service_pb2.ListModelsResponse(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        parent = client.location_path("[PROJECT]", "[LOCATION]")

        paged_list_response = client.list_models(parent)
        resources = list(paged_list_response)
        assert len(resources) == 1

        assert expected_response.model[0] == resources[0]

        assert len(channel.requests) == 1
        expected_request = service_pb2.ListModelsRequest(parent=parent)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_list_models_exception(self):
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup request
        parent = client.location_path("[PROJECT]", "[LOCATION]")

        paged_list_response = client.list_models(parent)
        with pytest.raises(CustomException):
            list(paged_list_response)

    def test_delete_model(self):
        # Setup Expected Response
        expected_response = {}
        expected_response = empty_pb2.Empty(**expected_response)
        operation = operations_pb2.Operation(
            name="operations/test_delete_model", done=True
        )
        operation.response.Pack(expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        name = client.model_path("[PROJECT]", "[LOCATION]", "[MODEL]")

        response = client.delete_model(name)
        result = response.result()
        assert expected_response == result

        assert len(channel.requests) == 1
        expected_request = service_pb2.DeleteModelRequest(name=name)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_delete_model_exception(self):
        # Setup Response
        error = status_pb2.Status()
        operation = operations_pb2.Operation(
            name="operations/test_delete_model_exception", done=True
        )
        operation.error.CopyFrom(error)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        name = client.model_path("[PROJECT]", "[LOCATION]", "[MODEL]")

        response = client.delete_model(name)
        exception = response.exception()
        assert exception.errors[0] == error

    def test_deploy_model(self):
        # Setup Expected Response
        expected_response = {}
        expected_response = empty_pb2.Empty(**expected_response)
        operation = operations_pb2.Operation(
            name="operations/test_deploy_model", done=True
        )
        operation.response.Pack(expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        name = client.model_path("[PROJECT]", "[LOCATION]", "[MODEL]")

        response = client.deploy_model(name)
        result = response.result()
        assert expected_response == result

        assert len(channel.requests) == 1
        expected_request = service_pb2.DeployModelRequest(name=name)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_deploy_model_exception(self):
        # Setup Response
        error = status_pb2.Status()
        operation = operations_pb2.Operation(
            name="operations/test_deploy_model_exception", done=True
        )
        operation.error.CopyFrom(error)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        name = client.model_path("[PROJECT]", "[LOCATION]", "[MODEL]")

        response = client.deploy_model(name)
        exception = response.exception()
        assert exception.errors[0] == error

    def test_undeploy_model(self):
        # Setup Expected Response
        expected_response = {}
        expected_response = empty_pb2.Empty(**expected_response)
        operation = operations_pb2.Operation(
            name="operations/test_undeploy_model", done=True
        )
        operation.response.Pack(expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        name = client.model_path("[PROJECT]", "[LOCATION]", "[MODEL]")

        response = client.undeploy_model(name)
        result = response.result()
        assert expected_response == result

        assert len(channel.requests) == 1
        expected_request = service_pb2.UndeployModelRequest(name=name)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_undeploy_model_exception(self):
        # Setup Response
        error = status_pb2.Status()
        operation = operations_pb2.Operation(
            name="operations/test_undeploy_model_exception", done=True
        )
        operation.error.CopyFrom(error)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        name = client.model_path("[PROJECT]", "[LOCATION]", "[MODEL]")

        response = client.undeploy_model(name)
        exception = response.exception()
        assert exception.errors[0] == error

    def test_get_model_evaluation(self):
        # Setup Expected Response
        name_2 = "name2-1052831874"
        annotation_spec_id = "annotationSpecId60690191"
        display_name = "displayName1615086568"
        evaluated_example_count = 277565350
        expected_response = {
            "name": name_2,
            "annotation_spec_id": annotation_spec_id,
            "display_name": display_name,
            "evaluated_example_count": evaluated_example_count,
        }
        expected_response = model_evaluation_pb2.ModelEvaluation(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        name = client.model_evaluation_path(
            "[PROJECT]", "[LOCATION]", "[MODEL]", "[MODEL_EVALUATION]"
        )

        response = client.get_model_evaluation(name)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = service_pb2.GetModelEvaluationRequest(name=name)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_get_model_evaluation_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup request
        name = client.model_evaluation_path(
            "[PROJECT]", "[LOCATION]", "[MODEL]", "[MODEL_EVALUATION]"
        )

        with pytest.raises(CustomException):
            client.get_model_evaluation(name)

    def test_export_model(self):
        # Setup Expected Response
        expected_response = {}
        expected_response = empty_pb2.Empty(**expected_response)
        operation = operations_pb2.Operation(
            name="operations/test_export_model", done=True
        )
        operation.response.Pack(expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        name = client.model_path("[PROJECT]", "[LOCATION]", "[MODEL]")
        output_config = {}

        response = client.export_model(name, output_config)
        result = response.result()
        assert expected_response == result

        assert len(channel.requests) == 1
        expected_request = service_pb2.ExportModelRequest(
            name=name, output_config=output_config
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_export_model_exception(self):
        # Setup Response
        error = status_pb2.Status()
        operation = operations_pb2.Operation(
            name="operations/test_export_model_exception", done=True
        )
        operation.error.CopyFrom(error)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        name = client.model_path("[PROJECT]", "[LOCATION]", "[MODEL]")
        output_config = {}

        response = client.export_model(name, output_config)
        exception = response.exception()
        assert exception.errors[0] == error

    def test_export_evaluated_examples(self):
        # Setup Expected Response
        expected_response = {}
        expected_response = empty_pb2.Empty(**expected_response)
        operation = operations_pb2.Operation(
            name="operations/test_export_evaluated_examples", done=True
        )
        operation.response.Pack(expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        name = client.model_path("[PROJECT]", "[LOCATION]", "[MODEL]")
        output_config = {}

        response = client.export_evaluated_examples(name, output_config)
        result = response.result()
        assert expected_response == result

        assert len(channel.requests) == 1
        expected_request = service_pb2.ExportEvaluatedExamplesRequest(
            name=name, output_config=output_config
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_export_evaluated_examples_exception(self):
        # Setup Response
        error = status_pb2.Status()
        operation = operations_pb2.Operation(
            name="operations/test_export_evaluated_examples_exception", done=True
        )
        operation.error.CopyFrom(error)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        name = client.model_path("[PROJECT]", "[LOCATION]", "[MODEL]")
        output_config = {}

        response = client.export_evaluated_examples(name, output_config)
        exception = response.exception()
        assert exception.errors[0] == error

    def test_list_model_evaluations(self):
        # Setup Expected Response
        next_page_token = ""
        model_evaluation_element = {}
        model_evaluation = [model_evaluation_element]
        expected_response = {
            "next_page_token": next_page_token,
            "model_evaluation": model_evaluation,
        }
        expected_response = service_pb2.ListModelEvaluationsResponse(
            **expected_response
        )

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        parent = client.model_path("[PROJECT]", "[LOCATION]", "[MODEL]")

        paged_list_response = client.list_model_evaluations(parent)
        resources = list(paged_list_response)
        assert len(resources) == 1

        assert expected_response.model_evaluation[0] == resources[0]

        assert len(channel.requests) == 1
        expected_request = service_pb2.ListModelEvaluationsRequest(parent=parent)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_list_model_evaluations_exception(self):
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup request
        parent = client.model_path("[PROJECT]", "[LOCATION]", "[MODEL]")

        paged_list_response = client.list_model_evaluations(parent)
        with pytest.raises(CustomException):
            list(paged_list_response)

    def test_get_annotation_spec(self):
        # Setup Expected Response
        name_2 = "name2-1052831874"
        display_name = "displayName1615086568"
        example_count = 1517063674
        expected_response = {
            "name": name_2,
            "display_name": display_name,
            "example_count": example_count,
        }
        expected_response = dataset_pb2.AnnotationSpec(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        name = client.annotation_spec_path(
            "[PROJECT]", "[LOCATION]", "[DATASET]", "[ANNOTATION_SPEC]"
        )

        response = client.get_annotation_spec(name)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = service_pb2.GetAnnotationSpecRequest(name=name)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_get_annotation_spec_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup request
        name = client.annotation_spec_path(
            "[PROJECT]", "[LOCATION]", "[DATASET]", "[ANNOTATION_SPEC]"
        )

        with pytest.raises(CustomException):
            client.get_annotation_spec(name)

    def test_get_table_spec(self):
        # Setup Expected Response
        name_2 = "name2-1052831874"
        time_column_spec_id = "timeColumnSpecId1558734824"
        row_count = 1340416618
        column_count = 122671386
        etag = "etag3123477"
        expected_response = {
            "name": name_2,
            "time_column_spec_id": time_column_spec_id,
            "row_count": row_count,
            "column_count": column_count,
            "etag": etag,
        }
        expected_response = table_spec_pb2.TableSpec(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        name = client.table_spec_path(
            "[PROJECT]", "[LOCATION]", "[DATASET]", "[TABLE_SPEC]"
        )

        response = client.get_table_spec(name)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = service_pb2.GetTableSpecRequest(name=name)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_get_table_spec_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup request
        name = client.table_spec_path(
            "[PROJECT]", "[LOCATION]", "[DATASET]", "[TABLE_SPEC]"
        )

        with pytest.raises(CustomException):
            client.get_table_spec(name)

    def test_list_table_specs(self):
        # Setup Expected Response
        next_page_token = ""
        table_specs_element = {}
        table_specs = [table_specs_element]
        expected_response = {
            "next_page_token": next_page_token,
            "table_specs": table_specs,
        }
        expected_response = service_pb2.ListTableSpecsResponse(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        parent = client.dataset_path("[PROJECT]", "[LOCATION]", "[DATASET]")

        paged_list_response = client.list_table_specs(parent)
        resources = list(paged_list_response)
        assert len(resources) == 1

        assert expected_response.table_specs[0] == resources[0]

        assert len(channel.requests) == 1
        expected_request = service_pb2.ListTableSpecsRequest(parent=parent)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_list_table_specs_exception(self):
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup request
        parent = client.dataset_path("[PROJECT]", "[LOCATION]", "[DATASET]")

        paged_list_response = client.list_table_specs(parent)
        with pytest.raises(CustomException):
            list(paged_list_response)

    def test_update_table_spec(self):
        # Setup Expected Response
        name = "name3373707"
        time_column_spec_id = "timeColumnSpecId1558734824"
        row_count = 1340416618
        column_count = 122671386
        etag = "etag3123477"
        expected_response = {
            "name": name,
            "time_column_spec_id": time_column_spec_id,
            "row_count": row_count,
            "column_count": column_count,
            "etag": etag,
        }
        expected_response = table_spec_pb2.TableSpec(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        table_spec = {}

        response = client.update_table_spec(table_spec)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = service_pb2.UpdateTableSpecRequest(table_spec=table_spec)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_update_table_spec_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup request
        table_spec = {}

        with pytest.raises(CustomException):
            client.update_table_spec(table_spec)

    def test_get_column_spec(self):
        # Setup Expected Response
        name_2 = "name2-1052831874"
        display_name = "displayName1615086568"
        etag = "etag3123477"
        expected_response = {"name": name_2, "display_name": display_name, "etag": etag}
        expected_response = column_spec_pb2.ColumnSpec(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        name = client.column_spec_path(
            "[PROJECT]", "[LOCATION]", "[DATASET]", "[TABLE_SPEC]", "[COLUMN_SPEC]"
        )

        response = client.get_column_spec(name)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = service_pb2.GetColumnSpecRequest(name=name)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_get_column_spec_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup request
        name = client.column_spec_path(
            "[PROJECT]", "[LOCATION]", "[DATASET]", "[TABLE_SPEC]", "[COLUMN_SPEC]"
        )

        with pytest.raises(CustomException):
            client.get_column_spec(name)

    def test_list_column_specs(self):
        # Setup Expected Response
        next_page_token = ""
        column_specs_element = {}
        column_specs = [column_specs_element]
        expected_response = {
            "next_page_token": next_page_token,
            "column_specs": column_specs,
        }
        expected_response = service_pb2.ListColumnSpecsResponse(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        parent = client.table_spec_path(
            "[PROJECT]", "[LOCATION]", "[DATASET]", "[TABLE_SPEC]"
        )

        paged_list_response = client.list_column_specs(parent)
        resources = list(paged_list_response)
        assert len(resources) == 1

        assert expected_response.column_specs[0] == resources[0]

        assert len(channel.requests) == 1
        expected_request = service_pb2.ListColumnSpecsRequest(parent=parent)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_list_column_specs_exception(self):
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup request
        parent = client.table_spec_path(
            "[PROJECT]", "[LOCATION]", "[DATASET]", "[TABLE_SPEC]"
        )

        paged_list_response = client.list_column_specs(parent)
        with pytest.raises(CustomException):
            list(paged_list_response)

    def test_update_column_spec(self):
        # Setup Expected Response
        name = "name3373707"
        display_name = "displayName1615086568"
        etag = "etag3123477"
        expected_response = {"name": name, "display_name": display_name, "etag": etag}
        expected_response = column_spec_pb2.ColumnSpec(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup Request
        column_spec = {}

        response = client.update_column_spec(column_spec)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = service_pb2.UpdateColumnSpecRequest(column_spec=column_spec)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_update_column_spec_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = automl_v1beta1.AutoMlClient()

        # Setup request
        column_spec = {}

        with pytest.raises(CustomException):
            client.update_column_spec(column_spec)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1beta1/proto/geometry.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1beta1/proto/geometry.proto",
    package="google.cloud.automl.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.automl.v1beta1P\001ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\312\002\033Google\\Cloud\\AutoMl\\V1beta1"
    ),
    serialized_pb=_b(
        '\n0google/cloud/automl_v1beta1/proto/geometry.proto\x12\x1bgoogle.cloud.automl.v1beta1\x1a\x1cgoogle/api/annotations.proto"(\n\x10NormalizedVertex\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02"Z\n\x0c\x42oundingPoly\x12J\n\x13normalized_vertices\x18\x02 \x03(\x0b\x32-.google.cloud.automl.v1beta1.NormalizedVertexB\x84\x01\n\x1f\x63om.google.cloud.automl.v1beta1P\x01ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\xca\x02\x1bGoogle\\Cloud\\AutoMl\\V1beta1b\x06proto3'
    ),
    dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR],
)


_NORMALIZEDVERTEX = _descriptor.Descriptor(
    name="NormalizedVertex",
    full_name="google.cloud.automl.v1beta1.NormalizedVertex",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="x",
            full_name="google.cloud.automl.v1beta1.NormalizedVertex.x",
            index=0,
            number=1,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="y",
            full_name="google.cloud.automl.v1beta1.NormalizedVertex.y",
            index=1,
            number=2,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=111,
    serialized_end=151,
)


_BOUNDINGPOLY = _descriptor.Descriptor(
    name="BoundingPoly",
    full_name="google.cloud.automl.v1beta1.BoundingPoly",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="normalized_vertices",
            full_name="google.cloud.automl.v1beta1.BoundingPoly.normalized_vertices",
            index=0,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=153,
    serialized_end=243,
)

_BOUNDINGPOLY.fields_by_name["normalized_vertices"].message_type = _NORMALIZEDVERTEX
DESCRIPTOR.message_types_by_name["NormalizedVertex"] = _NORMALIZEDVERTEX
DESCRIPTOR.message_types_by_name["BoundingPoly"] = _BOUNDINGPOLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NormalizedVertex = _reflection.GeneratedProtocolMessageType(
    "NormalizedVertex",
    (_message.Message,),
    dict(
        DESCRIPTOR=_NORMALIZEDVERTEX,
        __module__="google.cloud.automl_v1beta1.proto.geometry_pb2",
        __doc__="""Required. Horizontal coordinate.
  
  
  Attributes:
      y:
          Required. Vertical coordinate.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.NormalizedVertex)
    ),
)
_sym_db.RegisterMessage(NormalizedVertex)

BoundingPoly = _reflection.GeneratedProtocolMessageType(
    "BoundingPoly",
    (_message.Message,),
    dict(
        DESCRIPTOR=_BOUNDINGPOLY,
        __module__="google.cloud.automl_v1beta1.proto.geometry_pb2",
        __doc__="""A bounding polygon of a detected object on a plane. On output both
  vertices and normalized\_vertices are provided. The polygon is formed by
  connecting vertices in the order they are listed.
  
  
  Attributes:
      normalized_vertices:
          Output only . The bounding polygon normalized vertices.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.BoundingPoly)
    ),
)
_sym_db.RegisterMessage(BoundingPoly)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1beta1/proto/operations.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.cloud.automl_v1beta1.proto import (
    io_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_io__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    model_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_model__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    model_evaluation_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_model__evaluation__pb2,
)
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1beta1/proto/operations.proto",
    package="google.cloud.automl.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.automl.v1beta1P\001ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\312\002\033Google\\Cloud\\AutoMl\\V1beta1"
    ),
    serialized_pb=_b(
        '\n2google/cloud/automl_v1beta1/proto/operations.proto\x12\x1bgoogle.cloud.automl.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a*google/cloud/automl_v1beta1/proto/io.proto\x1a-google/cloud/automl_v1beta1/proto/model.proto\x1a\x38google/cloud/automl_v1beta1/proto/model_evaluation.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17google/rpc/status.proto"\x8b\x08\n\x11OperationMetadata\x12N\n\x0e\x64\x65lete_details\x18\x08 \x01(\x0b\x32\x34.google.cloud.automl.v1beta1.DeleteOperationMetadataH\x00\x12Y\n\x14\x64\x65ploy_model_details\x18\x18 \x01(\x0b\x32\x39.google.cloud.automl.v1beta1.DeployModelOperationMetadataH\x00\x12]\n\x16undeploy_model_details\x18\x19 \x01(\x0b\x32;.google.cloud.automl.v1beta1.UndeployModelOperationMetadataH\x00\x12Y\n\x14\x63reate_model_details\x18\n \x01(\x0b\x32\x39.google.cloud.automl.v1beta1.CreateModelOperationMetadataH\x00\x12W\n\x13import_data_details\x18\x0f \x01(\x0b\x32\x38.google.cloud.automl.v1beta1.ImportDataOperationMetadataH\x00\x12[\n\x15\x62\x61tch_predict_details\x18\x10 \x01(\x0b\x32:.google.cloud.automl.v1beta1.BatchPredictOperationMetadataH\x00\x12W\n\x13\x65xport_data_details\x18\x15 \x01(\x0b\x32\x38.google.cloud.automl.v1beta1.ExportDataOperationMetadataH\x00\x12Y\n\x14\x65xport_model_details\x18\x16 \x01(\x0b\x32\x39.google.cloud.automl.v1beta1.ExportModelOperationMetadataH\x00\x12r\n!export_evaluated_examples_details\x18\x1a \x01(\x0b\x32\x45.google.cloud.automl.v1beta1.ExportEvaluatedExamplesOperationMetadataH\x00\x12\x18\n\x10progress_percent\x18\r \x01(\x05\x12,\n\x10partial_failures\x18\x02 \x03(\x0b\x32\x12.google.rpc.Status\x12/\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bupdate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\t\n\x07\x64\x65tails"\x19\n\x17\x44\x65leteOperationMetadata"\x1e\n\x1c\x44\x65ployModelOperationMetadata" \n\x1eUndeployModelOperationMetadata"\x1e\n\x1c\x43reateModelOperationMetadata"\x1d\n\x1bImportDataOperationMetadata"\xef\x01\n\x1b\x45xportDataOperationMetadata\x12\x62\n\x0boutput_info\x18\x01 \x01(\x0b\x32M.google.cloud.automl.v1beta1.ExportDataOperationMetadata.ExportDataOutputInfo\x1al\n\x14\x45xportDataOutputInfo\x12\x1e\n\x14gcs_output_directory\x18\x01 \x01(\tH\x00\x12!\n\x17\x62igquery_output_dataset\x18\x02 \x01(\tH\x00\x42\x11\n\x0foutput_location"\xc3\x02\n\x1d\x42\x61tchPredictOperationMetadata\x12J\n\x0cinput_config\x18\x01 \x01(\x0b\x32\x34.google.cloud.automl.v1beta1.BatchPredictInputConfig\x12\x66\n\x0boutput_info\x18\x02 \x01(\x0b\x32Q.google.cloud.automl.v1beta1.BatchPredictOperationMetadata.BatchPredictOutputInfo\x1an\n\x16\x42\x61tchPredictOutputInfo\x12\x1e\n\x14gcs_output_directory\x18\x01 \x01(\tH\x00\x12!\n\x17\x62igquery_output_dataset\x18\x02 \x01(\tH\x00\x42\x11\n\x0foutput_location"\xbb\x01\n\x1c\x45xportModelOperationMetadata\x12\x64\n\x0boutput_info\x18\x02 \x01(\x0b\x32O.google.cloud.automl.v1beta1.ExportModelOperationMetadata.ExportModelOutputInfo\x1a\x35\n\x15\x45xportModelOutputInfo\x12\x1c\n\x14gcs_output_directory\x18\x01 \x01(\t"\xee\x01\n(ExportEvaluatedExamplesOperationMetadata\x12|\n\x0boutput_info\x18\x02 \x01(\x0b\x32g.google.cloud.automl.v1beta1.ExportEvaluatedExamplesOperationMetadata.ExportEvaluatedExamplesOutputInfo\x1a\x44\n!ExportEvaluatedExamplesOutputInfo\x12\x1f\n\x17\x62igquery_output_dataset\x18\x02 \x01(\tB\x84\x01\n\x1f\x63om.google.cloud.automl.v1beta1P\x01ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\xca\x02\x1bGoogle\\Cloud\\AutoMl\\V1beta1b\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_io__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_model__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_model__evaluation__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_rpc_dot_status__pb2.DESCRIPTOR,
    ],
)


_OPERATIONMETADATA = _descriptor.Descriptor(
    name="OperationMetadata",
    full_name="google.cloud.automl.v1beta1.OperationMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="delete_details",
            full_name="google.cloud.automl.v1beta1.OperationMetadata.delete_details",
            index=0,
            number=8,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="deploy_model_details",
            full_name="google.cloud.automl.v1beta1.OperationMetadata.deploy_model_details",
            index=1,
            number=24,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="undeploy_model_details",
            full_name="google.cloud.automl.v1beta1.OperationMetadata.undeploy_model_details",
            index=2,
            number=25,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="create_model_details",
            full_name="google.cloud.automl.v1beta1.OperationMetadata.create_model_details",
            index=3,
            number=10,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="import_data_details",
            full_name="google.cloud.automl.v1beta1.OperationMetadata.import_data_details",
            index=4,
            number=15,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="batch_predict_details",
            full_name="google.cloud.automl.v1beta1.OperationMetadata.batch_predict_details",
            index=5,
            number=16,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="export_data_details",
            full_name="google.cloud.automl.v1beta1.OperationMetadata.export_data_details",
            index=6,
            number=21,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="export_model_details",
            full_name="google.cloud.automl.v1beta1.OperationMetadata.export_model_details",
            index=7,
            number=22,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="export_evaluated_examples_details",
            full_name="google.cloud.automl.v1beta1.OperationMetadata.export_evaluated_examples_details",
            index=8,
            number=26,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="progress_percent",
            full_name="google.cloud.automl.v1beta1.OperationMetadata.progress_percent",
            index=9,
            number=13,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="partial_failures",
            full_name="google.cloud.automl.v1beta1.OperationMetadata.partial_failures",
            index=10,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="create_time",
            full_name="google.cloud.automl.v1beta1.OperationMetadata.create_time",
            index=11,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_time",
            full_name="google.cloud.automl.v1beta1.OperationMetadata.update_time",
            index=12,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="details",
            full_name="google.cloud.automl.v1beta1.OperationMetadata.details",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=350,
    serialized_end=1385,
)


_DELETEOPERATIONMETADATA = _descriptor.Descriptor(
    name="DeleteOperationMetadata",
    full_name="google.cloud.automl.v1beta1.DeleteOperationMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1387,
    serialized_end=1412,
)


_DEPLOYMODELOPERATIONMETADATA = _descriptor.Descriptor(
    name="DeployModelOperationMetadata",
    full_name="google.cloud.automl.v1beta1.DeployModelOperationMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1414,
    serialized_end=1444,
)


_UNDEPLOYMODELOPERATIONMETADATA = _descriptor.Descriptor(
    name="UndeployModelOperationMetadata",
    full_name="google.cloud.automl.v1beta1.UndeployModelOperationMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1446,
    serialized_end=1478,
)


_CREATEMODELOPERATIONMETADATA = _descriptor.Descriptor(
    name="CreateModelOperationMetadata",
    full_name="google.cloud.automl.v1beta1.CreateModelOperationMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1480,
    serialized_end=1510,
)


_IMPORTDATAOPERATIONMETADATA = _descriptor.Descriptor(
    name="ImportDataOperationMetadata",
    full_name="google.cloud.automl.v1beta1.ImportDataOperationMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1512,
    serialized_end=1541,
)


_EXPORTDATAOPERATIONMETADATA_EXPORTDATAOUTPUTINFO = _descriptor.Descriptor(
    name="ExportDataOutputInfo",
    full_name="google.cloud.automl.v1beta1.ExportDataOperationMetadata.ExportDataOutputInfo",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="gcs_output_directory",
            full_name="google.cloud.automl.v1beta1.ExportDataOperationMetadata.ExportDataOutputInfo.gcs_output_directory",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="bigquery_output_dataset",
            full_name="google.cloud.automl.v1beta1.ExportDataOperationMetadata.ExportDataOutputInfo.bigquery_output_dataset",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="output_location",
            full_name="google.cloud.automl.v1beta1.ExportDataOperationMetadata.ExportDataOutputInfo.output_location",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=1675,
    serialized_end=1783,
)

_EXPORTDATAOPERATIONMETADATA = _descriptor.Descriptor(
    name="ExportDataOperationMetadata",
    full_name="google.cloud.automl.v1beta1.ExportDataOperationMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="output_info",
            full_name="google.cloud.automl.v1beta1.ExportDataOperationMetadata.output_info",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[_EXPORTDATAOPERATIONMETADATA_EXPORTDATAOUTPUTINFO],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1544,
    serialized_end=1783,
)


_BATCHPREDICTOPERATIONMETADATA_BATCHPREDICTOUTPUTINFO = _descriptor.Descriptor(
    name="BatchPredictOutputInfo",
    full_name="google.cloud.automl.v1beta1.BatchPredictOperationMetadata.BatchPredictOutputInfo",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="gcs_output_directory",
            full_name="google.cloud.automl.v1beta1.BatchPredictOperationMetadata.BatchPredictOutputInfo.gcs_output_directory",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="bigquery_output_dataset",
            full_name="google.cloud.automl.v1beta1.BatchPredictOperationMetadata.BatchPredictOutputInfo.bigquery_output_dataset",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="output_location",
            full_name="google.cloud.automl.v1beta1.BatchPredictOperationMetadata.BatchPredictOutputInfo.output_location",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=1999,
    serialized_end=2109,
)

_BATCHPREDICTOPERATIONMETADATA = _descriptor.Descriptor(
    name="BatchPredictOperationMetadata",
    full_name="google.cloud.automl.v1beta1.BatchPredictOperationMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="input_config",
            full_name="google.cloud.automl.v1beta1.BatchPredictOperationMetadata.input_config",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="output_info",
            full_name="google.cloud.automl.v1beta1.BatchPredictOperationMetadata.output_info",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_BATCHPREDICTOPERATIONMETADATA_BATCHPREDICTOUTPUTINFO],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1786,
    serialized_end=2109,
)


_EXPORTMODELOPERATIONMETADATA_EXPORTMODELOUTPUTINFO = _descriptor.Descriptor(
    name="ExportModelOutputInfo",
    full_name="google.cloud.automl.v1beta1.ExportModelOperationMetadata.ExportModelOutputInfo",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="gcs_output_directory",
            full_name="google.cloud.automl.v1beta1.ExportModelOperationMetadata.ExportModelOutputInfo.gcs_output_directory",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2246,
    serialized_end=2299,
)

_EXPORTMODELOPERATIONMETADATA = _descriptor.Descriptor(
    name="ExportModelOperationMetadata",
    full_name="google.cloud.automl.v1beta1.ExportModelOperationMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="output_info",
            full_name="google.cloud.automl.v1beta1.ExportModelOperationMetadata.output_info",
            index=0,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[_EXPORTMODELOPERATIONMETADATA_EXPORTMODELOUTPUTINFO],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2112,
    serialized_end=2299,
)


_EXPORTEVALUATEDEXAMPLESOPERATIONMETADATA_EXPORTEVALUATEDEXAMPLESOUTPUTINFO = _descriptor.Descriptor(
    name="ExportEvaluatedExamplesOutputInfo",
    full_name="google.cloud.automl.v1beta1.ExportEvaluatedExamplesOperationMetadata.ExportEvaluatedExamplesOutputInfo",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="bigquery_output_dataset",
            full_name="google.cloud.automl.v1beta1.ExportEvaluatedExamplesOperationMetadata.ExportEvaluatedExamplesOutputInfo.bigquery_output_dataset",
            index=0,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2472,
    serialized_end=2540,
)

_EXPORTEVALUATEDEXAMPLESOPERATIONMETADATA = _descriptor.Descriptor(
    name="ExportEvaluatedExamplesOperationMetadata",
    full_name="google.cloud.automl.v1beta1.ExportEvaluatedExamplesOperationMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="output_info",
            full_name="google.cloud.automl.v1beta1.ExportEvaluatedExamplesOperationMetadata.output_info",
            index=0,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[
        _EXPORTEVALUATEDEXAMPLESOPERATIONMETADATA_EXPORTEVALUATEDEXAMPLESOUTPUTINFO
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2302,
    serialized_end=2540,
)

_OPERATIONMETADATA.fields_by_name[
    "delete_details"
].message_type = _DELETEOPERATIONMETADATA
_OPERATIONMETADATA.fields_by_name[
    "deploy_model_details"
].message_type = _DEPLOYMODELOPERATIONMETADATA
_OPERATIONMETADATA.fields_by_name[
    "undeploy_model_details"
].message_type = _UNDEPLOYMODELOPERATIONMETADATA
_OPERATIONMETADATA.fields_by_name[
    "create_model_details"
].message_type = _CREATEMODELOPERATIONMETADATA
_OPERATIONMETADATA.fields_by_name[
    "import_data_details"
].message_type = _IMPORTDATAOPERATIONMETADATA
_OPERATIONMETADATA.fields_by_name[
    "batch_predict_details"
].message_type = _BATCHPREDICTOPERATIONMETADATA
_OPERATIONMETADATA.fields_by_name[
    "export_data_details"
].message_type = _EXPORTDATAOPERATIONMETADATA
_OPERATIONMETADATA.fields_by_name[
    "export_model_details"
].message_type = _EXPORTMODELOPERATIONMETADATA
_OPERATIONMETADATA.fields_by_name[
    "export_evaluated_examples_details"
].message_type = _EXPORTEVALUATEDEXAMPLESOPERATIONMETADATA
_OPERATIONMETADATA.fields_by_name[
    "partial_failures"
].message_type = google_dot_rpc_dot_status__pb2._STATUS
_OPERATIONMETADATA.fields_by_name[
    "create_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_OPERATIONMETADATA.fields_by_name[
    "update_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_OPERATIONMETADATA.oneofs_by_name["details"].fields.append(
    _OPERATIONMETADATA.fields_by_name["delete_details"]
)
_OPERATIONMETADATA.fields_by_name[
    "delete_details"
].containing_oneof = _OPERATIONMETADATA.oneofs_by_name["details"]
_OPERATIONMETADATA.oneofs_by_name["details"].fields.append(
    _OPERATIONMETADATA.fields_by_name["deploy_model_details"]
)
_OPERATIONMETADATA.fields_by_name[
    "deploy_model_details"
].containing_oneof = _OPERATIONMETADATA.oneofs_by_name["details"]
_OPERATIONMETADATA.oneofs_by_name["details"].fields.append(
    _OPERATIONMETADATA.fields_by_name["undeploy_model_details"]
)
_OPERATIONMETADATA.fields_by_name[
    "undeploy_model_details"
].containing_oneof = _OPERATIONMETADATA.oneofs_by_name["details"]
_OPERATIONMETADATA.oneofs_by_name["details"].fields.append(
    _OPERATIONMETADATA.fields_by_name["create_model_details"]
)
_OPERATIONMETADATA.fields_by_name[
    "create_model_details"
].containing_oneof = _OPERATIONMETADATA.oneofs_by_name["details"]
_OPERATIONMETADATA.oneofs_by_name["details"].fields.append(
    _OPERATIONMETADATA.fields_by_name["import_data_details"]
)
_OPERATIONMETADATA.fields_by_name[
    "import_data_details"
].containing_oneof = _OPERATIONMETADATA.oneofs_by_name["details"]
_OPERATIONMETADATA.oneofs_by_name["details"].fields.append(
    _OPERATIONMETADATA.fields_by_name["batch_predict_details"]
)
_OPERATIONMETADATA.fields_by_name[
    "batch_predict_details"
].containing_oneof = _OPERATIONMETADATA.oneofs_by_name["details"]
_OPERATIONMETADATA.oneofs_by_name["details"].fields.append(
    _OPERATIONMETADATA.fields_by_name["export_data_details"]
)
_OPERATIONMETADATA.fields_by_name[
    "export_data_details"
].containing_oneof = _OPERATIONMETADATA.oneofs_by_name["details"]
_OPERATIONMETADATA.oneofs_by_name["details"].fields.append(
    _OPERATIONMETADATA.fields_by_name["export_model_details"]
)
_OPERATIONMETADATA.fields_by_name[
    "export_model_details"
].containing_oneof = _OPERATIONMETADATA.oneofs_by_name["details"]
_OPERATIONMETADATA.oneofs_by_name["details"].fields.append(
    _OPERATIONMETADATA.fields_by_name["export_evaluated_examples_details"]
)
_OPERATIONMETADATA.fields_by_name[
    "export_evaluated_examples_details"
].containing_oneof = _OPERATIONMETADATA.oneofs_by_name["details"]
_EXPORTDATAOPERATIONMETADATA_EXPORTDATAOUTPUTINFO.containing_type = (
    _EXPORTDATAOPERATIONMETADATA
)
_EXPORTDATAOPERATIONMETADATA_EXPORTDATAOUTPUTINFO.oneofs_by_name[
    "output_location"
].fields.append(
    _EXPORTDATAOPERATIONMETADATA_EXPORTDATAOUTPUTINFO.fields_by_name[
        "gcs_output_directory"
    ]
)
_EXPORTDATAOPERATIONMETADATA_EXPORTDATAOUTPUTINFO.fields_by_name[
    "gcs_output_directory"
].containing_oneof = _EXPORTDATAOPERATIONMETADATA_EXPORTDATAOUTPUTINFO.oneofs_by_name[
    "output_location"
]
_EXPORTDATAOPERATIONMETADATA_EXPORTDATAOUTPUTINFO.oneofs_by_name[
    "output_location"
].fields.append(
    _EXPORTDATAOPERATIONMETADATA_EXPORTDATAOUTPUTINFO.fields_by_name[
        "bigquery_output_dataset"
    ]
)
_EXPORTDATAOPERATIONMETADATA_EXPORTDATAOUTPUTINFO.fields_by_name[
    "bigquery_output_dataset"
].containing_oneof = _EXPORTDATAOPERATIONMETADATA_EXPORTDATAOUTPUTINFO.oneofs_by_name[
    "output_location"
]
_EXPORTDATAOPERATIONMETADATA.fields_by_name[
    "output_info"
].message_type = _EXPORTDATAOPERATIONMETADATA_EXPORTDATAOUTPUTINFO
_BATCHPREDICTOPERATIONMETADATA_BATCHPREDICTOUTPUTINFO.containing_type = (
    _BATCHPREDICTOPERATIONMETADATA
)
_BATCHPREDICTOPERATIONMETADATA_BATCHPREDICTOUTPUTINFO.oneofs_by_name[
    "output_location"
].fields.append(
    _BATCHPREDICTOPERATIONMETADATA_BATCHPREDICTOUTPUTINFO.fields_by_name[
        "gcs_output_directory"
    ]
)
_BATCHPREDICTOPERATIONMETADATA_BATCHPREDICTOUTPUTINFO.fields_by_name[
    "gcs_output_directory"
].containing_oneof = _BATCHPREDICTOPERATIONMETADATA_BATCHPREDICTOUTPUTINFO.oneofs_by_name[
    "output_location"
]
_BATCHPREDICTOPERATIONMETADATA_BATCHPREDICTOUTPUTINFO.oneofs_by_name[
    "output_location"
].fields.append(
    _BATCHPREDICTOPERATIONMETADATA_BATCHPREDICTOUTPUTINFO.fields_by_name[
        "bigquery_output_dataset"
    ]
)
_BATCHPREDICTOPERATIONMETADATA_BATCHPREDICTOUTPUTINFO.fields_by_name[
    "bigquery_output_dataset"
].containing_oneof = _BATCHPREDICTOPERATIONMETADATA_BATCHPREDICTOUTPUTINFO.oneofs_by_name[
    "output_location"
]
_BATCHPREDICTOPERATIONMETADATA.fields_by_name[
    "input_config"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_io__pb2._BATCHPREDICTINPUTCONFIG
)
_BATCHPREDICTOPERATIONMETADATA.fields_by_name[
    "output_info"
].message_type = _BATCHPREDICTOPERATIONMETADATA_BATCHPREDICTOUTPUTINFO
_EXPORTMODELOPERATIONMETADATA_EXPORTMODELOUTPUTINFO.containing_type = (
    _EXPORTMODELOPERATIONMETADATA
)
_EXPORTMODELOPERATIONMETADATA.fields_by_name[
    "output_info"
].message_type = _EXPORTMODELOPERATIONMETADATA_EXPORTMODELOUTPUTINFO
_EXPORTEVALUATEDEXAMPLESOPERATIONMETADATA_EXPORTEVALUATEDEXAMPLESOUTPUTINFO.containing_type = (
    _EXPORTEVALUATEDEXAMPLESOPERATIONMETADATA
)
_EXPORTEVALUATEDEXAMPLESOPERATIONMETADATA.fields_by_name[
    "output_info"
].message_type = (
    _EXPORTEVALUATEDEXAMPLESOPERATIONMETADATA_EXPORTEVALUATEDEXAMPLESOUTPUTINFO
)
DESCRIPTOR.message_types_by_name["OperationMetadata"] = _OPERATIONMETADATA
DESCRIPTOR.message_types_by_name["DeleteOperationMetadata"] = _DELETEOPERATIONMETADATA
DESCRIPTOR.message_types_by_name[
    "DeployModelOperationMetadata"
] = _DEPLOYMODELOPERATIONMETADATA
DESCRIPTOR.message_types_by_name[
    "UndeployModelOperationMetadata"
] = _UNDEPLOYMODELOPERATIONMETADATA
DESCRIPTOR.message_types_by_name[
    "CreateModelOperationMetadata"
] = _CREATEMODELOPERATIONMETADATA
DESCRIPTOR.message_types_by_name[
    "ImportDataOperationMetadata"
] = _IMPORTDATAOPERATIONMETADATA
DESCRIPTOR.message_types_by_name[
    "ExportDataOperationMetadata"
] = _EXPORTDATAOPERATIONMETADATA
DESCRIPTOR.message_types_by_name[
    "BatchPredictOperationMetadata"
] = _BATCHPREDICTOPERATIONMETADATA
DESCRIPTOR.message_types_by_name[
    "ExportModelOperationMetadata"
] = _EXPORTMODELOPERATIONMETADATA
DESCRIPTOR.message_types_by_name[
    "ExportEvaluatedExamplesOperationMetadata"
] = _EXPORTEVALUATEDEXAMPLESOPERATIONMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OperationMetadata = _reflection.GeneratedProtocolMessageType(
    "OperationMetadata",
    (_message.Message,),
    dict(
        DESCRIPTOR=_OPERATIONMETADATA,
        __module__="google.cloud.automl_v1beta1.proto.operations_pb2",
        __doc__="""Metadata used across all long running operations returned by AutoML API.
  
  
  Attributes:
      details:
          Ouptut only. Details of specific operation. Even if this field
          is empty, the presence allows to distinguish different types
          of operations.
      delete_details:
          Details of a Delete operation.
      deploy_model_details:
          Details of a DeployModel operation.
      undeploy_model_details:
          Details of an UndeployModel operation.
      create_model_details:
          Details of CreateModel operation.
      import_data_details:
          Details of ImportData operation.
      batch_predict_details:
          Details of BatchPredict operation.
      export_data_details:
          Details of ExportData operation.
      export_model_details:
          Details of ExportModel operation.
      export_evaluated_examples_details:
          Details of ExportEvaluatedExamples operation.
      progress_percent:
          Output only. Progress of operation. Range: [0, 100]. Not used
          currently.
      partial_failures:
          Output only. Partial failures encountered. E.g. single files
          that couldn't be read. This field should never exceed 20
          entries. Status details field will contain standard GCP error
          details.
      create_time:
          Output only. Time when the operation was created.
      update_time:
          Output only. Time when the operation was updated for the last
          time.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.OperationMetadata)
    ),
)
_sym_db.RegisterMessage(OperationMetadata)

DeleteOperationMetadata = _reflection.GeneratedProtocolMessageType(
    "DeleteOperationMetadata",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DELETEOPERATIONMETADATA,
        __module__="google.cloud.automl_v1beta1.proto.operations_pb2",
        __doc__="""Details of operations that perform deletes of any entities.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.DeleteOperationMetadata)
    ),
)
_sym_db.RegisterMessage(DeleteOperationMetadata)

DeployModelOperationMetadata = _reflection.GeneratedProtocolMessageType(
    "DeployModelOperationMetadata",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DEPLOYMODELOPERATIONMETADATA,
        __module__="google.cloud.automl_v1beta1.proto.operations_pb2",
        __doc__="""Details of DeployModel operation.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.DeployModelOperationMetadata)
    ),
)
_sym_db.RegisterMessage(DeployModelOperationMetadata)

UndeployModelOperationMetadata = _reflection.GeneratedProtocolMessageType(
    "UndeployModelOperationMetadata",
    (_message.Message,),
    dict(
        DESCRIPTOR=_UNDEPLOYMODELOPERATIONMETADATA,
        __module__="google.cloud.automl_v1beta1.proto.operations_pb2",
        __doc__="""Details of UndeployModel operation.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.UndeployModelOperationMetadata)
    ),
)
_sym_db.RegisterMessage(UndeployModelOperationMetadata)

CreateModelOperationMetadata = _reflection.GeneratedProtocolMessageType(
    "CreateModelOperationMetadata",
    (_message.Message,),
    dict(
        DESCRIPTOR=_CREATEMODELOPERATIONMETADATA,
        __module__="google.cloud.automl_v1beta1.proto.operations_pb2",
        __doc__="""Details of CreateModel operation.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.CreateModelOperationMetadata)
    ),
)
_sym_db.RegisterMessage(CreateModelOperationMetadata)

ImportDataOperationMetadata = _reflection.GeneratedProtocolMessageType(
    "ImportDataOperationMetadata",
    (_message.Message,),
    dict(
        DESCRIPTOR=_IMPORTDATAOPERATIONMETADATA,
        __module__="google.cloud.automl_v1beta1.proto.operations_pb2",
        __doc__="""Details of ImportData operation.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ImportDataOperationMetadata)
    ),
)
_sym_db.RegisterMessage(ImportDataOperationMetadata)

ExportDataOperationMetadata = _reflection.GeneratedProtocolMessageType(
    "ExportDataOperationMetadata",
    (_message.Message,),
    dict(
        ExportDataOutputInfo=_reflection.GeneratedProtocolMessageType(
            "ExportDataOutputInfo",
            (_message.Message,),
            dict(
                DESCRIPTOR=_EXPORTDATAOPERATIONMETADATA_EXPORTDATAOUTPUTINFO,
                __module__="google.cloud.automl_v1beta1.proto.operations_pb2",
                __doc__="""Further describes this export data's output. Supplements
    [OutputConfig][google.cloud.automl.v1beta1.OutputConfig].
    
    
    Attributes:
        output_location:
            The output location to which the exported data is written.
        gcs_output_directory:
            The full path of the Google Cloud Storage directory created,
            into which the exported data is written.
        bigquery_output_dataset:
            The path of the BigQuery dataset created, in
            bq://projectId.bqDatasetId format, into which the exported
            data is written.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ExportDataOperationMetadata.ExportDataOutputInfo)
            ),
        ),
        DESCRIPTOR=_EXPORTDATAOPERATIONMETADATA,
        __module__="google.cloud.automl_v1beta1.proto.operations_pb2",
        __doc__="""Details of ExportData operation.
  
  
  Attributes:
      output_info:
          Output only. Information further describing this export data's
          output.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ExportDataOperationMetadata)
    ),
)
_sym_db.RegisterMessage(ExportDataOperationMetadata)
_sym_db.RegisterMessage(ExportDataOperationMetadata.ExportDataOutputInfo)

BatchPredictOperationMetadata = _reflection.GeneratedProtocolMessageType(
    "BatchPredictOperationMetadata",
    (_message.Message,),
    dict(
        BatchPredictOutputInfo=_reflection.GeneratedProtocolMessageType(
            "BatchPredictOutputInfo",
            (_message.Message,),
            dict(
                DESCRIPTOR=_BATCHPREDICTOPERATIONMETADATA_BATCHPREDICTOUTPUTINFO,
                __module__="google.cloud.automl_v1beta1.proto.operations_pb2",
                __doc__="""Further describes this batch predict's output. Supplements
    
    [BatchPredictionOutputConfig][google.cloud.automl.v1beta1.BatchPredictionOutputConfig].
    
    
    Attributes:
        output_location:
            The output location into which prediction output is written.
        gcs_output_directory:
            The full path of the Google Cloud Storage directory created,
            into which the prediction output is written.
        bigquery_output_dataset:
            The path of the BigQuery dataset created, in
            bq://projectId.bqDatasetId format, into which the prediction
            output is written.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.BatchPredictOperationMetadata.BatchPredictOutputInfo)
            ),
        ),
        DESCRIPTOR=_BATCHPREDICTOPERATIONMETADATA,
        __module__="google.cloud.automl_v1beta1.proto.operations_pb2",
        __doc__="""Details of BatchPredict operation.
  
  
  Attributes:
      input_config:
          Output only. The input config that was given upon starting
          this batch predict operation.
      output_info:
          Output only. Information further describing this batch
          predict's output.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.BatchPredictOperationMetadata)
    ),
)
_sym_db.RegisterMessage(BatchPredictOperationMetadata)
_sym_db.RegisterMessage(BatchPredictOperationMetadata.BatchPredictOutputInfo)

ExportModelOperationMetadata = _reflection.GeneratedProtocolMessageType(
    "ExportModelOperationMetadata",
    (_message.Message,),
    dict(
        ExportModelOutputInfo=_reflection.GeneratedProtocolMessageType(
            "ExportModelOutputInfo",
            (_message.Message,),
            dict(
                DESCRIPTOR=_EXPORTMODELOPERATIONMETADATA_EXPORTMODELOUTPUTINFO,
                __module__="google.cloud.automl_v1beta1.proto.operations_pb2",
                __doc__="""Further describes the output of model export. Supplements
    
    [ModelExportOutputConfig][google.cloud.automl.v1beta1.ModelExportOutputConfig].
    
    
    Attributes:
        gcs_output_directory:
            The full path of the Google Cloud Storage directory created,
            into which the model will be exported.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ExportModelOperationMetadata.ExportModelOutputInfo)
            ),
        ),
        DESCRIPTOR=_EXPORTMODELOPERATIONMETADATA,
        __module__="google.cloud.automl_v1beta1.proto.operations_pb2",
        __doc__="""Details of ExportModel operation.
  
  
  Attributes:
      output_info:
          Output only. Information further describing the output of this
          model export.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ExportModelOperationMetadata)
    ),
)
_sym_db.RegisterMessage(ExportModelOperationMetadata)
_sym_db.RegisterMessage(ExportModelOperationMetadata.ExportModelOutputInfo)

ExportEvaluatedExamplesOperationMetadata = _reflection.GeneratedProtocolMessageType(
    "ExportEvaluatedExamplesOperationMetadata",
    (_message.Message,),
    dict(
        ExportEvaluatedExamplesOutputInfo=_reflection.GeneratedProtocolMessageType(
            "ExportEvaluatedExamplesOutputInfo",
            (_message.Message,),
            dict(
                DESCRIPTOR=_EXPORTEVALUATEDEXAMPLESOPERATIONMETADATA_EXPORTEVALUATEDEXAMPLESOUTPUTINFO,
                __module__="google.cloud.automl_v1beta1.proto.operations_pb2",
                __doc__="""Further describes the output of the evaluated examples export.
    Supplements
    
    [ExportEvaluatedExamplesOutputConfig][google.cloud.automl.v1beta1.ExportEvaluatedExamplesOutputConfig].
    
    
    Attributes:
        bigquery_output_dataset:
            The path of the BigQuery dataset created, in
            bq://projectId.bqDatasetId format, into which the output of
            export evaluated examples is written.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ExportEvaluatedExamplesOperationMetadata.ExportEvaluatedExamplesOutputInfo)
            ),
        ),
        DESCRIPTOR=_EXPORTEVALUATEDEXAMPLESOPERATIONMETADATA,
        __module__="google.cloud.automl_v1beta1.proto.operations_pb2",
        __doc__="""Details of EvaluatedExamples operation.
  
  
  Attributes:
      output_info:
          Output only. Information further describing the output of this
          evaluated examples export.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ExportEvaluatedExamplesOperationMetadata)
    ),
)
_sym_db.RegisterMessage(ExportEvaluatedExamplesOperationMetadata)
_sym_db.RegisterMessage(
    ExportEvaluatedExamplesOperationMetadata.ExportEvaluatedExamplesOutputInfo
)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



config = {
    "interfaces": {
        "google.cloud.automl.v1beta1.AutoMl": {
            "retry_codes": {
                "idempotent": ["DEADLINE_EXCEEDED", "UNAVAILABLE"],
                "non_idempotent": [],
            },
            "retry_params": {
                "default": {
                    "initial_retry_delay_millis": 100,
                    "retry_delay_multiplier": 1.3,
                    "max_retry_delay_millis": 60000,
                    "initial_rpc_timeout_millis": 20000,
                    "rpc_timeout_multiplier": 1.0,
                    "max_rpc_timeout_millis": 20000,
                    "total_timeout_millis": 600000,
                }
            },
            "methods": {
                "CreateDataset": {
                    "timeout_millis": 5000,
                    "retry_codes_name": "non_idempotent",
                    "retry_params_name": "default",
                },
                "UpdateDataset": {
                    "timeout_millis": 5000,
                    "retry_codes_name": "non_idempotent",
                    "retry_params_name": "default",
                },
                "GetDataset": {
                    "timeout_millis": 5000,
                    "retry_codes_name": "idempotent",
                    "retry_params_name": "default",
                },
                "ListDatasets": {
                    "timeout_millis": 50000,
                    "retry_codes_name": "idempotent",
                    "retry_params_name": "default",
                },
                "DeleteDataset": {
                    "timeout_millis": 5000,
                    "retry_codes_name": "idempotent",
                    "retry_params_name": "default",
                },
                "ImportData": {
                    "timeout_millis": 20000,
                    "retry_codes_name": "non_idempotent",
                    "retry_params_name": "default",
                },
                "ExportData": {
                    "timeout_millis": 5000,
                    "retry_codes_name": "non_idempotent",
                    "retry_params_name": "default",
                },
                "CreateModel": {
                    "timeout_millis": 20000,
                    "retry_codes_name": "non_idempotent",
                    "retry_params_name": "default",
                },
                "GetModel": {
                    "timeout_millis": 5000,
                    "retry_codes_name": "idempotent",
                    "retry_params_name": "default",
                },
                "ListModels": {
                    "timeout_millis": 50000,
                    "retry_codes_name": "idempotent",
                    "retry_params_name": "default",
                },
                "DeleteModel": {
                    "timeout_millis": 5000,
                    "retry_codes_name": "idempotent",
                    "retry_params_name": "default",
                },
                "DeployModel": {
                    "timeout_millis": 5000,
                    "retry_codes_name": "non_idempotent",
                    "retry_params_name": "default",
                },
                "UndeployModel": {
                    "timeout_millis": 5000,
                    "retry_codes_name": "non_idempotent",
                    "retry_params_name": "default",
                },
                "GetModelEvaluation": {
                    "timeout_millis": 5000,
                    "retry_codes_name": "idempotent",
                    "retry_params_name": "default",
                },
                "ExportModel": {
                    "timeout_millis": 5000,
                    "retry_codes_name": "non_idempotent",
                    "retry_params_name": "default",
                },
                "ExportEvaluatedExamples": {
                    "timeout_millis": 5000,
                    "retry_codes_name": "non_idempotent",
                    "retry_params_name": "default",
                },
                "ListModelEvaluations": {
                    "timeout_millis": 50000,
                    "retry_codes_name": "non_idempotent",
                    "retry_params_name": "default",
                },
                "GetAnnotationSpec": {
                    "timeout_millis": 5000,
                    "retry_codes_name": "idempotent",
                    "retry_params_name": "default",
                },
                "GetTableSpec": {
                    "timeout_millis": 5000,
                    "retry_codes_name": "idempotent",
                    "retry_params_name": "default",
                },
                "ListTableSpecs": {
                    "timeout_millis": 5000,
                    "retry_codes_name": "idempotent",
                    "retry_params_name": "default",
                },
                "UpdateTableSpec": {
                    "timeout_millis": 5000,
                    "retry_codes_name": "non_idempotent",
                    "retry_params_name": "default",
                },
                "GetColumnSpec": {
                    "timeout_millis": 5000,
                    "retry_codes_name": "idempotent",
                    "retry_params_name": "default",
                },
                "ListColumnSpecs": {
                    "timeout_millis": 5000,
                    "retry_codes_name": "idempotent",
                    "retry_params_name": "default",
                },
                "UpdateColumnSpec": {
                    "timeout_millis": 5000,
                    "retry_codes_name": "non_idempotent",
                    "retry_params_name": "default",
                },
            },
        }
    }
}



# -*- coding: utf-8 -*-
#
# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from __future__ import absolute_import
import sys

from google.api_core.protobuf_helpers import get_messages

from google.cloud.automl_v1beta1.proto import annotation_payload_pb2
from google.cloud.automl_v1beta1.proto import classification_pb2
from google.cloud.automl_v1beta1.proto import column_spec_pb2
from google.cloud.automl_v1beta1.proto import data_items_pb2
from google.cloud.automl_v1beta1.proto import data_stats_pb2
from google.cloud.automl_v1beta1.proto import data_types_pb2
from google.cloud.automl_v1beta1.proto import dataset_pb2
from google.cloud.automl_v1beta1.proto import detection_pb2
from google.cloud.automl_v1beta1.proto import geometry_pb2
from google.cloud.automl_v1beta1.proto import image_pb2
from google.cloud.automl_v1beta1.proto import io_pb2
from google.cloud.automl_v1beta1.proto import model_evaluation_pb2
from google.cloud.automl_v1beta1.proto import model_pb2
from google.cloud.automl_v1beta1.proto import operations_pb2 as proto_operations_pb2
from google.cloud.automl_v1beta1.proto import prediction_service_pb2
from google.cloud.automl_v1beta1.proto import ranges_pb2
from google.cloud.automl_v1beta1.proto import regression_pb2
from google.cloud.automl_v1beta1.proto import service_pb2
from google.cloud.automl_v1beta1.proto import table_spec_pb2
from google.cloud.automl_v1beta1.proto import tables_pb2
from google.cloud.automl_v1beta1.proto import temporal_pb2
from google.cloud.automl_v1beta1.proto import text_extraction_pb2
from google.cloud.automl_v1beta1.proto import text_pb2
from google.cloud.automl_v1beta1.proto import text_segment_pb2
from google.cloud.automl_v1beta1.proto import text_sentiment_pb2
from google.cloud.automl_v1beta1.proto import translation_pb2
from google.cloud.automl_v1beta1.proto import video_pb2
from google.longrunning import operations_pb2 as longrunning_operations_pb2
from google.protobuf import any_pb2
from google.protobuf import duration_pb2
from google.protobuf import field_mask_pb2
from google.protobuf import struct_pb2
from google.protobuf import timestamp_pb2
from google.rpc import status_pb2

_shared_modules = [
    longrunning_operations_pb2,
    any_pb2,
    duration_pb2,
    field_mask_pb2,
    struct_pb2,
    timestamp_pb2,
    status_pb2,
]

_local_modules = [
    annotation_payload_pb2,
    classification_pb2,
    column_spec_pb2,
    data_items_pb2,
    data_stats_pb2,
    data_types_pb2,
    dataset_pb2,
    detection_pb2,
    geometry_pb2,
    image_pb2,
    io_pb2,
    model_evaluation_pb2,
    model_pb2,
    proto_operations_pb2,
    prediction_service_pb2,
    ranges_pb2,
    regression_pb2,
    service_pb2,
    table_spec_pb2,
    tables_pb2,
    temporal_pb2,
    text_extraction_pb2,
    text_pb2,
    text_segment_pb2,
    text_sentiment_pb2,
    translation_pb2,
    video_pb2,
]

names = []

for module in _shared_modules:
    for name, message in get_messages(module).items():
        setattr(sys.modules[__name__], name, message)
        names.append(name)
for module in _local_modules:
    for name, message in get_messages(module).items():
        message.__module__ = "google.cloud.automl_v1beta1.types"
        setattr(sys.modules[__name__], name, message)
        names.append(name)

__all__ = tuple(sorted(names))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1beta1/proto/dataset.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.cloud.automl_v1beta1.proto import (
    annotation_payload_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_annotation__payload__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    data_items_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_data__items__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    image_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_image__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    tables_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_tables__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    text_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_text__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    translation_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_translation__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    video_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_video__pb2,
)
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1beta1/proto/dataset.proto",
    package="google.cloud.automl.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.automl.v1beta1P\001ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\312\002\033Google\\Cloud\\AutoMl\\V1beta1"
    ),
    serialized_pb=_b(
        '\n/google/cloud/automl_v1beta1/proto/dataset.proto\x12\x1bgoogle.cloud.automl.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a:google/cloud/automl_v1beta1/proto/annotation_payload.proto\x1a\x32google/cloud/automl_v1beta1/proto/data_items.proto\x1a-google/cloud/automl_v1beta1/proto/image.proto\x1a.google/cloud/automl_v1beta1/proto/tables.proto\x1a,google/cloud/automl_v1beta1/proto/text.proto\x1a\x33google/cloud/automl_v1beta1/proto/translation.proto\x1a-google/cloud/automl_v1beta1/proto/video.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\xfb\x07\n\x07\x44\x61taset\x12_\n\x1ctranslation_dataset_metadata\x18\x17 \x01(\x0b\x32\x37.google.cloud.automl.v1beta1.TranslationDatasetMetadataH\x00\x12p\n%image_classification_dataset_metadata\x18\x18 \x01(\x0b\x32?.google.cloud.automl.v1beta1.ImageClassificationDatasetMetadataH\x00\x12n\n$text_classification_dataset_metadata\x18\x19 \x01(\x0b\x32>.google.cloud.automl.v1beta1.TextClassificationDatasetMetadataH\x00\x12s\n\'image_object_detection_dataset_metadata\x18\x1a \x01(\x0b\x32@.google.cloud.automl.v1beta1.ImageObjectDetectionDatasetMetadataH\x00\x12p\n%video_classification_dataset_metadata\x18\x1f \x01(\x0b\x32?.google.cloud.automl.v1beta1.VideoClassificationDatasetMetadataH\x00\x12\x66\n text_extraction_dataset_metadata\x18\x1c \x01(\x0b\x32:.google.cloud.automl.v1beta1.TextExtractionDatasetMetadataH\x00\x12\x64\n\x1ftext_sentiment_dataset_metadata\x18\x1e \x01(\x0b\x32\x39.google.cloud.automl.v1beta1.TextSentimentDatasetMetadataH\x00\x12U\n\x17tables_dataset_metadata\x18! \x01(\x0b\x32\x32.google.cloud.automl.v1beta1.TablesDatasetMetadataH\x00\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x15\n\rexample_count\x18\x15 \x01(\x05\x12/\n\x0b\x63reate_time\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04\x65tag\x18\x11 \x01(\tB\x12\n\x10\x64\x61taset_metadata"K\n\x0e\x41nnotationSpec\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x15\n\rexample_count\x18\t \x01(\x05\x42\x84\x01\n\x1f\x63om.google.cloud.automl.v1beta1P\x01ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\xca\x02\x1bGoogle\\Cloud\\AutoMl\\V1beta1b\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_annotation__payload__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_data__items__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_image__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_tables__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_text__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_translation__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_video__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
    ],
)


_DATASET = _descriptor.Descriptor(
    name="Dataset",
    full_name="google.cloud.automl.v1beta1.Dataset",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="translation_dataset_metadata",
            full_name="google.cloud.automl.v1beta1.Dataset.translation_dataset_metadata",
            index=0,
            number=23,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="image_classification_dataset_metadata",
            full_name="google.cloud.automl.v1beta1.Dataset.image_classification_dataset_metadata",
            index=1,
            number=24,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="text_classification_dataset_metadata",
            full_name="google.cloud.automl.v1beta1.Dataset.text_classification_dataset_metadata",
            index=2,
            number=25,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="image_object_detection_dataset_metadata",
            full_name="google.cloud.automl.v1beta1.Dataset.image_object_detection_dataset_metadata",
            index=3,
            number=26,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="video_classification_dataset_metadata",
            full_name="google.cloud.automl.v1beta1.Dataset.video_classification_dataset_metadata",
            index=4,
            number=31,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="text_extraction_dataset_metadata",
            full_name="google.cloud.automl.v1beta1.Dataset.text_extraction_dataset_metadata",
            index=5,
            number=28,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="text_sentiment_dataset_metadata",
            full_name="google.cloud.automl.v1beta1.Dataset.text_sentiment_dataset_metadata",
            index=6,
            number=30,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="tables_dataset_metadata",
            full_name="google.cloud.automl.v1beta1.Dataset.tables_dataset_metadata",
            index=7,
            number=33,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1beta1.Dataset.name",
            index=8,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.automl.v1beta1.Dataset.display_name",
            index=9,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.automl.v1beta1.Dataset.description",
            index=10,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="example_count",
            full_name="google.cloud.automl.v1beta1.Dataset.example_count",
            index=11,
            number=21,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="create_time",
            full_name="google.cloud.automl.v1beta1.Dataset.create_time",
            index=12,
            number=14,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="etag",
            full_name="google.cloud.automl.v1beta1.Dataset.etag",
            index=13,
            number=17,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="dataset_metadata",
            full_name="google.cloud.automl.v1beta1.Dataset.dataset_metadata",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=497,
    serialized_end=1516,
)


_ANNOTATIONSPEC = _descriptor.Descriptor(
    name="AnnotationSpec",
    full_name="google.cloud.automl.v1beta1.AnnotationSpec",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1beta1.AnnotationSpec.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.automl.v1beta1.AnnotationSpec.display_name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="example_count",
            full_name="google.cloud.automl.v1beta1.AnnotationSpec.example_count",
            index=2,
            number=9,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1518,
    serialized_end=1593,
)

_DATASET.fields_by_name[
    "translation_dataset_metadata"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_translation__pb2._TRANSLATIONDATASETMETADATA
)
_DATASET.fields_by_name[
    "image_classification_dataset_metadata"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_image__pb2._IMAGECLASSIFICATIONDATASETMETADATA
)
_DATASET.fields_by_name[
    "text_classification_dataset_metadata"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_text__pb2._TEXTCLASSIFICATIONDATASETMETADATA
)
_DATASET.fields_by_name[
    "image_object_detection_dataset_metadata"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_image__pb2._IMAGEOBJECTDETECTIONDATASETMETADATA
)
_DATASET.fields_by_name[
    "video_classification_dataset_metadata"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_video__pb2._VIDEOCLASSIFICATIONDATASETMETADATA
)
_DATASET.fields_by_name[
    "text_extraction_dataset_metadata"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_text__pb2._TEXTEXTRACTIONDATASETMETADATA
)
_DATASET.fields_by_name[
    "text_sentiment_dataset_metadata"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_text__pb2._TEXTSENTIMENTDATASETMETADATA
)
_DATASET.fields_by_name[
    "tables_dataset_metadata"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_tables__pb2._TABLESDATASETMETADATA
)
_DATASET.fields_by_name[
    "create_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DATASET.oneofs_by_name["dataset_metadata"].fields.append(
    _DATASET.fields_by_name["translation_dataset_metadata"]
)
_DATASET.fields_by_name[
    "translation_dataset_metadata"
].containing_oneof = _DATASET.oneofs_by_name["dataset_metadata"]
_DATASET.oneofs_by_name["dataset_metadata"].fields.append(
    _DATASET.fields_by_name["image_classification_dataset_metadata"]
)
_DATASET.fields_by_name[
    "image_classification_dataset_metadata"
].containing_oneof = _DATASET.oneofs_by_name["dataset_metadata"]
_DATASET.oneofs_by_name["dataset_metadata"].fields.append(
    _DATASET.fields_by_name["text_classification_dataset_metadata"]
)
_DATASET.fields_by_name[
    "text_classification_dataset_metadata"
].containing_oneof = _DATASET.oneofs_by_name["dataset_metadata"]
_DATASET.oneofs_by_name["dataset_metadata"].fields.append(
    _DATASET.fields_by_name["image_object_detection_dataset_metadata"]
)
_DATASET.fields_by_name[
    "image_object_detection_dataset_metadata"
].containing_oneof = _DATASET.oneofs_by_name["dataset_metadata"]
_DATASET.oneofs_by_name["dataset_metadata"].fields.append(
    _DATASET.fields_by_name["video_classification_dataset_metadata"]
)
_DATASET.fields_by_name[
    "video_classification_dataset_metadata"
].containing_oneof = _DATASET.oneofs_by_name["dataset_metadata"]
_DATASET.oneofs_by_name["dataset_metadata"].fields.append(
    _DATASET.fields_by_name["text_extraction_dataset_metadata"]
)
_DATASET.fields_by_name[
    "text_extraction_dataset_metadata"
].containing_oneof = _DATASET.oneofs_by_name["dataset_metadata"]
_DATASET.oneofs_by_name["dataset_metadata"].fields.append(
    _DATASET.fields_by_name["text_sentiment_dataset_metadata"]
)
_DATASET.fields_by_name[
    "text_sentiment_dataset_metadata"
].containing_oneof = _DATASET.oneofs_by_name["dataset_metadata"]
_DATASET.oneofs_by_name["dataset_metadata"].fields.append(
    _DATASET.fields_by_name["tables_dataset_metadata"]
)
_DATASET.fields_by_name[
    "tables_dataset_metadata"
].containing_oneof = _DATASET.oneofs_by_name["dataset_metadata"]
DESCRIPTOR.message_types_by_name["Dataset"] = _DATASET
DESCRIPTOR.message_types_by_name["AnnotationSpec"] = _ANNOTATIONSPEC
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Dataset = _reflection.GeneratedProtocolMessageType(
    "Dataset",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DATASET,
        __module__="google.cloud.automl_v1beta1.proto.dataset_pb2",
        __doc__="""A workspace for solving a single, particular machine learning (ML)
  problem. A workspace contains examples that may be annotated.
  
  
  Attributes:
      dataset_metadata:
          Required. The dataset metadata that is specific to the problem
          type.
      translation_dataset_metadata:
          Metadata for a dataset used for translation.
      image_classification_dataset_metadata:
          Metadata for a dataset used for image classification.
      text_classification_dataset_metadata:
          Metadata for a dataset used for text classification.
      image_object_detection_dataset_metadata:
          Metadata for a dataset used for image object detection.
      video_classification_dataset_metadata:
          Metadata for a dataset used for video classification.
      text_extraction_dataset_metadata:
          Metadata for a dataset used for text extraction.
      text_sentiment_dataset_metadata:
          Metadata for a dataset used for text sentiment.
      tables_dataset_metadata:
          Metadata for a dataset used for Tables.
      name:
          Output only. The resource name of the dataset. Form: ``project
          s/{project_id}/locations/{location_id}/datasets/{dataset_id}``
      display_name:
          Required. The name of the dataset to show in the interface.
          The name can be up to 32 characters long and can consist only
          of ASCII Latin letters A-Z and a-z, underscores (\_), and
          ASCII digits 0-9.
      description:
          User-provided description of the dataset. The description can
          be up to 25000 characters long.
      example_count:
          Output only. The number of examples in the dataset.
      create_time:
          Output only. Timestamp when this dataset was created.
      etag:
          Used to perform consistent read-modify-write updates. If not
          set, a blind "overwrite" update happens.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.Dataset)
    ),
)
_sym_db.RegisterMessage(Dataset)

AnnotationSpec = _reflection.GeneratedProtocolMessageType(
    "AnnotationSpec",
    (_message.Message,),
    dict(
        DESCRIPTOR=_ANNOTATIONSPEC,
        __module__="google.cloud.automl_v1beta1.proto.dataset_pb2",
        __doc__="""A definition of an annotation.
  
  
  Attributes:
      name:
          Output only. Resource name of the annotation spec. Form:  'pro
          jects/{project\_id}/locations/{location\_id}/datasets/{dataset
          \_id}/annotationSpecs/{annotation\_spec\_id}'
      display_name:
          Required. The name of the annotation spec to show in the
          interface. The name can be up to 32 characters long and can
          consist only of ASCII Latin letters A-Z and a-z, underscores
          (\_), and ASCII digits 0-9.
      example_count:
          Output only. The number of examples in the parent dataset
          labeled by the annotation spec.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.AnnotationSpec)
    ),
)
_sym_db.RegisterMessage(AnnotationSpec)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
#
# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Accesses the google.cloud.automl.v1beta1 PredictionService API."""

import pkg_resources
import warnings

from google.oauth2 import service_account
import google.api_core.gapic_v1.client_info
import google.api_core.gapic_v1.config
import google.api_core.gapic_v1.method
import google.api_core.gapic_v1.routing_header
import google.api_core.grpc_helpers
import google.api_core.operation
import google.api_core.operations_v1
import google.api_core.path_template
import grpc

from google.cloud.automl_v1beta1.gapic import enums
from google.cloud.automl_v1beta1.gapic import prediction_service_client_config
from google.cloud.automl_v1beta1.gapic.transports import (
    prediction_service_grpc_transport,
)
from google.cloud.automl_v1beta1.proto import column_spec_pb2
from google.cloud.automl_v1beta1.proto import data_items_pb2
from google.cloud.automl_v1beta1.proto import dataset_pb2
from google.cloud.automl_v1beta1.proto import image_pb2
from google.cloud.automl_v1beta1.proto import io_pb2
from google.cloud.automl_v1beta1.proto import model_evaluation_pb2
from google.cloud.automl_v1beta1.proto import model_pb2
from google.cloud.automl_v1beta1.proto import operations_pb2 as proto_operations_pb2
from google.cloud.automl_v1beta1.proto import prediction_service_pb2
from google.cloud.automl_v1beta1.proto import prediction_service_pb2_grpc
from google.cloud.automl_v1beta1.proto import service_pb2
from google.cloud.automl_v1beta1.proto import service_pb2_grpc
from google.cloud.automl_v1beta1.proto import table_spec_pb2
from google.longrunning import operations_pb2 as longrunning_operations_pb2
from google.protobuf import empty_pb2
from google.protobuf import field_mask_pb2

_GAPIC_LIBRARY_VERSION = pkg_resources.get_distribution("google-cloud-automl").version


class PredictionServiceClient(object):
    """
    AutoML Prediction API.

    On any input that is documented to expect a string parameter in
    snake\_case or kebab-case, either of those cases is accepted.
    """

    SERVICE_ADDRESS = "automl.googleapis.com:443"
    """The default address of the service."""

    # The name of the interface for this client. This is the key used to
    # find the method configuration in the client_config dictionary.
    _INTERFACE_NAME = "google.cloud.automl.v1beta1.PredictionService"

    @classmethod
    def from_service_account_file(cls, filename, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
        file.

        Args:
            filename (str): The path to the service account private key json
                file.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            PredictionServiceClient: The constructed client.
        """
        credentials = service_account.Credentials.from_service_account_file(filename)
        kwargs["credentials"] = credentials
        return cls(*args, **kwargs)

    from_service_account_json = from_service_account_file

    @classmethod
    def model_path(cls, project, location, model):
        """Return a fully-qualified model string."""
        return google.api_core.path_template.expand(
            "projects/{project}/locations/{location}/models/{model}",
            project=project,
            location=location,
            model=model,
        )

    def __init__(
        self,
        transport=None,
        channel=None,
        credentials=None,
        client_config=None,
        client_info=None,
    ):
        """Constructor.

        Args:
            transport (Union[~.PredictionServiceGrpcTransport,
                    Callable[[~.Credentials, type], ~.PredictionServiceGrpcTransport]): A transport
                instance, responsible for actually making the API calls.
                The default transport uses the gRPC protocol.
                This argument may also be a callable which returns a
                transport instance. Callables will be sent the credentials
                as the first argument and the default transport class as
                the second argument.
            channel (grpc.Channel): DEPRECATED. A ``Channel`` instance
                through which to make calls. This argument is mutually exclusive
                with ``credentials``; providing both will raise an exception.
            credentials (google.auth.credentials.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
                This argument is mutually exclusive with providing a
                transport instance to ``transport``; doing so will raise
                an exception.
            client_config (dict): DEPRECATED. A dictionary of call options for
                each method. If not specified, the default configuration is used.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
        """
        # Raise deprecation warnings for things we want to go away.
        if client_config is not None:
            warnings.warn(
                "The `client_config` argument is deprecated.",
                PendingDeprecationWarning,
                stacklevel=2,
            )
        else:
            client_config = prediction_service_client_config.config

        if channel:
            warnings.warn(
                "The `channel` argument is deprecated; use " "`transport` instead.",
                PendingDeprecationWarning,
                stacklevel=2,
            )

        # Instantiate the transport.
        # The transport is responsible for handling serialization and
        # deserialization and actually sending data to the service.
        if transport:
            if callable(transport):
                self.transport = transport(
                    credentials=credentials,
                    default_class=prediction_service_grpc_transport.PredictionServiceGrpcTransport,
                )
            else:
                if credentials:
                    raise ValueError(
                        "Received both a transport instance and "
                        "credentials; these are mutually exclusive."
                    )
                self.transport = transport
        else:
            self.transport = prediction_service_grpc_transport.PredictionServiceGrpcTransport(
                address=self.SERVICE_ADDRESS, channel=channel, credentials=credentials
            )

        if client_info is None:
            client_info = google.api_core.gapic_v1.client_info.ClientInfo(
                gapic_version=_GAPIC_LIBRARY_VERSION
            )
        else:
            client_info.gapic_version = _GAPIC_LIBRARY_VERSION
        self._client_info = client_info

        # Parse out the default settings for retry and timeout for each RPC
        # from the client configuration.
        # (Ordinarily, these are the defaults specified in the `*_config.py`
        # file next to this one.)
        self._method_configs = google.api_core.gapic_v1.config.parse_method_configs(
            client_config["interfaces"][self._INTERFACE_NAME]
        )

        # Save a dictionary of cached API call functions.
        # These are the actual callables which invoke the proper
        # transport methods, wrapped with `wrap_method` to add retry,
        # timeout, and the like.
        self._inner_api_calls = {}

    # Service calls
    def predict(
        self,
        name,
        payload,
        params=None,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Perform an online prediction. The prediction result will be directly
        returned in the response. Available for following ML problems, and their
        expected request payloads:

        -  Image Classification - Image in .JPEG, .GIF or .PNG format,
           image\_bytes up to 30MB.
        -  Image Object Detection - Image in .JPEG, .GIF or .PNG format,
           image\_bytes up to 30MB.
        -  Text Classification - TextSnippet, content up to 10,000 characters,
           UTF-8 encoded.
        -  Text Extraction - TextSnippet, content up to 30,000 characters, UTF-8
           NFC encoded. \* Translation - TextSnippet, content up to 25,000
           characters, UTF-8 encoded.
        -  Tables - Row, with column values matching the columns of the model,
           up to 5MB.
        -  Text Sentiment - TextSnippet, content up 500 characters, UTF-8
           encoded.

        Example:
            >>> from google.cloud import automl_v1beta1
            >>>
            >>> client = automl_v1beta1.PredictionServiceClient()
            >>>
            >>> name = client.model_path('[PROJECT]', '[LOCATION]', '[MODEL]')
            >>>
            >>> # TODO: Initialize `payload`:
            >>> payload = {}
            >>>
            >>> response = client.predict(name, payload)

        Args:
            name (str): Name of the model requested to serve the prediction.
            payload (Union[dict, ~google.cloud.automl_v1beta1.types.ExamplePayload]): Required.
                Payload to perform a prediction on. The payload must match the
                problem type that the model was trained to solve.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.automl_v1beta1.types.ExamplePayload`
            params (dict[str -> str]): Additional domain-specific parameters, any string must be up to 25000
                characters long.

                -  For Image Classification:

                   ``score_threshold`` - (float) A value from 0.0 to 1.0. When the model
                   makes predictions for an image, it will only produce results that
                   have at least this confidence score. The default is 0.5.

                -  For Image Object Detection: ``score_threshold`` - (float) When Model
                   detects objects on the image, it will only produce bounding boxes
                   which have at least this confidence score. Value in 0 to 1 range,
                   default is 0.5. ``max_bounding_box_count`` - (int64) No more than
                   this number of bounding boxes will be returned in the response.
                   Default is 100, the requested value may be limited by server.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will not
                be retried.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.cloud.automl_v1beta1.types.PredictResponse` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "predict" not in self._inner_api_calls:
            self._inner_api_calls[
                "predict"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.predict,
                default_retry=self._method_configs["Predict"].retry,
                default_timeout=self._method_configs["Predict"].timeout,
                client_info=self._client_info,
            )

        request = prediction_service_pb2.PredictRequest(
            name=name, payload=payload, params=params
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("name", name)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        return self._inner_api_calls["predict"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def batch_predict(
        self,
        name,
        input_config,
        output_config,
        params=None,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Perform a batch prediction. Unlike the online ``Predict``, batch
        prediction result won't be immediately available in the response.
        Instead, a long running operation object is returned. User can poll the
        operation result via ``GetOperation`` method. Once the operation is
        done, ``BatchPredictResult`` is returned in the ``response`` field.
        Available for following ML problems:

        -  Video Classification
        -  Text Extraction
        -  Tables

        Example:
            >>> from google.cloud import automl_v1beta1
            >>>
            >>> client = automl_v1beta1.PredictionServiceClient()
            >>>
            >>> name = client.model_path('[PROJECT]', '[LOCATION]', '[MODEL]')
            >>>
            >>> # TODO: Initialize `input_config`:
            >>> input_config = {}
            >>>
            >>> # TODO: Initialize `output_config`:
            >>> output_config = {}
            >>>
            >>> response = client.batch_predict(name, input_config, output_config)
            >>>
            >>> def callback(operation_future):
            ...     # Handle result.
            ...     result = operation_future.result()
            >>>
            >>> response.add_done_callback(callback)
            >>>
            >>> # Handle metadata.
            >>> metadata = response.metadata()

        Args:
            name (str): Name of the model requested to serve the batch prediction.
            input_config (Union[dict, ~google.cloud.automl_v1beta1.types.BatchPredictInputConfig]): Required. The input configuration for batch prediction.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.automl_v1beta1.types.BatchPredictInputConfig`
            output_config (Union[dict, ~google.cloud.automl_v1beta1.types.BatchPredictOutputConfig]): Required. The Configuration specifying where output predictions should
                be written.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.automl_v1beta1.types.BatchPredictOutputConfig`
            params (dict[str -> str]): Additional domain-specific parameters for the predictions, any string
                must be up to 25000 characters long.

                -  For Video Classification : ``score_threshold`` - (float) A value from
                   0.0 to 1.0. When the model makes predictions for a video, it will
                   only produce results that have at least this confidence score. The
                   default is 0.5. ``segment_classification`` - (boolean) Set to true to
                   request segment-level classification. AutoML Video Intelligence
                   returns labels and their confidence scores for the entire segment of
                   the video that user specified in the request configuration. The
                   default is "true". ``shot_classification`` - (boolean) Set to true to
                   request shot-level classification. AutoML Video Intelligence
                   determines the boundaries for each camera shot in the entire segment
                   of the video that user specified in the request configuration. AutoML
                   Video Intelligence then returns labels and their confidence scores
                   for each detected shot, along with the start and end time of the
                   shot. WARNING: Model evaluation is not done for this classification
                   type, the quality of it depends on training data, but there are no
                   metrics provided to describe that quality. The default is "false".
                   ``1s_interval_classification`` - (boolean) Set to true to request
                   classification for a video at one-second intervals. AutoML Video
                   Intelligence returns labels and their confidence scores for each
                   second of the entire segment of the video that user specified in the
                   request configuration. WARNING: Model evaluation is not done for this
                   classification type, the quality of it depends on training data, but
                   there are no metrics provided to describe that quality. The default
                   is "false".
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will not
                be retried.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.cloud.automl_v1beta1.types._OperationFuture` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "batch_predict" not in self._inner_api_calls:
            self._inner_api_calls[
                "batch_predict"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.batch_predict,
                default_retry=self._method_configs["BatchPredict"].retry,
                default_timeout=self._method_configs["BatchPredict"].timeout,
                client_info=self._client_info,
            )

        request = prediction_service_pb2.BatchPredictRequest(
            name=name,
            input_config=input_config,
            output_config=output_config,
            params=params,
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("name", name)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        operation = self._inner_api_calls["batch_predict"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )
        return google.api_core.operation.from_gapic(
            operation,
            self.transport._operations_client,
            prediction_service_pb2.BatchPredictResult,
            metadata_type=proto_operations_pb2.OperationMetadata,
        )
